@@ -1,7 +1,6 @@
 package Test::MockTime::HiRes;
 use strict;
 use warnings;
-use 5.010;
 
 # cpan
 use Test::More;
@@ -18,7 +17,7 @@ our @EXPORT = qw(
     mock_time
 );
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 my $datetime_was_loaded;
 
@@ -72,7 +71,7 @@ BEGIN {
 
 sub time (&;@) {
     my $original = shift;
-    $Test::MockTime::fixed // $original->(@_) + $Test::MockTime::offset;
+    defined $Test::MockTime::fixed ? $Test::MockTime::fixed : $original->(@_) + $Test::MockTime::offset;
 }
 
 sub gettimeofday() {
